==> defi_state_querier-0.1.4-py3-none-any.whl: defi_services/services/lending/lending_info/ethereum/morpho_aave_v3_eth.py <==
MORPHO_AAVE_V3_ETH = {
    "name": "Morpho Lending Pool",
    "comptrollerAddress": "0x33333aea097c193e66081e930c33020272b33333",
    "poolToken": "0x9994e35db50125e0df82e4c2dde62496ce330999",
    "type": "LENDING_POOL",
    "forked": "morpho-aave-v3",
    "reservesList": {
        "0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2": {
            "tToken": "0x4d5f47fa6a74757f35c14fd3a6ef8e3c9bc514e8",
            "sdToken": "0x102633152313c81cd80419b6ecf66d14ad68949a",
            "dToken": "0xea51d7853eefb32b6ee06b1c12e6dcca88be0ffe",
            "liquidationThreshold": 0.83
        },
        "0x7f39c581f595b53c5cb19bd0b3f8da6c935e2ca0": {
            "tToken": "0x0b925ed163218f6662a35e0f0371ac234f9e9371",
            "sdToken": "0x39739943199c0fbfe9e5f1b5b160cd73a64cb85d",
            "dToken": "0xc96113eed8cab59cd8a66813bcb0ceb29f06d2e4",
            "liquidationThreshold": 0.8
        },
        "0x6b175474e89094c44da98b954eedeac495271d0f": {
            "tToken": "0x018008bfb33d285247a21d44e50697654f754e63",
            "sdToken": "0x413adac9e2ef8683adf5ddaece8f19613d60d1bb",
            "dToken": "0xcf8d0c70c850859266f5c338b38f9d663181c314",
            "liquidationThreshold": 0.8
        },
        "0xa0b86991c6218b36c1d19d4a2e9eb0ce3606eb48": {
            "tToken": "0x98c23e9d8f34fefb1b7bd6a91b7ff122f4e16f5c",
            "sdToken": "0xb0fe3d292f4bd50de902ba5bdf120ad66e9d7a39",
            "dToken": "0x72e95b8931767c79ba4eee721354d6e99a61d004",
            "liquidationThreshold": 0.8
        },
        "0x2260fac5e5542a773aa44fbcfedf7c193bc2c599": {
            "tToken": "0x5ee5bf7ae06d1be5997a1a72006fe6c607ec6de8",
            "sdToken": "0xa1773f1ccf6db192ad8fe826d15fe1d328b03284",
            "dToken": "0x40aabef1aa8f0eec637e0e7d92fbffb2f26a8b7b",
            "liquidationThreshold": 0.78
        },
        "0xae78736cd615f374d3085123a210448e74fc6393": {
            "tToken": "0xcc9ee9483f662091a1de4795249e24ac0ac2630f",
            "sdToken": "0x1d1906f909cae494c7441604dafdddbd0485a925",
            "dToken": "0xae8593dd575fe29a9745056aa91c4b746eee62c8",
            "liquidationThreshold": 0.74
        },
        "0xbe9895146f7af43049ca1c1ae358b0541ea49704": {
            "tToken": "0x977b6fc5de62598b08c85ac8cf2b745874e8b78c",
            "sdToken": "0x82be6012cea6d147b968ebaea5ceecf6a5b4f493",
            "dToken": "0x0c91bca95b5fe69164ce583a2ec9429a569798ed",
            "liquidationThreshold": 0.74
        },
    }
}

==> defi_state_querier-0.4.22-py3-none-any.whl: defi_services/services/lending/lending_info/ethereum/morpho_aave_v3_eth.py <==
MORPHO_AAVE_V3_ETH = {
    "name": "Morpho Lending Pool",
    "comptrollerAddress": "0x33333aea097c193e66081e930c33020272b33333",
    "poolToken": "0x9994e35db50125e0df82e4c2dde62496ce330999",
    "type": "LENDING_POOL",
    "forked": "morpho-aavev3",
    "reservesList": {
        "0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2": {
            "tToken": "0x4d5f47fa6a74757f35c14fd3a6ef8e3c9bc514e8",
            "sdToken": "0x102633152313c81cd80419b6ecf66d14ad68949a",
            "dToken": "0xea51d7853eefb32b6ee06b1c12e6dcca88be0ffe",
            "liquidationThreshold": 0.83
        },
        "0x7f39c581f595b53c5cb19bd0b3f8da6c935e2ca0": {
            "tToken": "0x0b925ed163218f6662a35e0f0371ac234f9e9371",
            "sdToken": "0x39739943199c0fbfe9e5f1b5b160cd73a64cb85d",
            "dToken": "0xc96113eed8cab59cd8a66813bcb0ceb29f06d2e4",
            "liquidationThreshold": 0.81
        },
        "0x2260fac5e5542a773aa44fbcfedf7c193bc2c599": {
            "tToken": "0x5ee5bf7ae06d1be5997a1a72006fe6c607ec6de8",
            "sdToken": "0xa1773f1ccf6db192ad8fe826d15fe1d328b03284",
            "dToken": "0x40aabef1aa8f0eec637e0e7d92fbffb2f26a8b7b",
            "liquidationThreshold": 0.78
        },
        "0xa0b86991c6218b36c1d19d4a2e9eb0ce3606eb48": {
            "tToken": "0x98c23e9d8f34fefb1b7bd6a91b7ff122f4e16f5c",
            "sdToken": "0xb0fe3d292f4bd50de902ba5bdf120ad66e9d7a39",
            "dToken": "0x72e95b8931767c79ba4eee721354d6e99a61d004",
            "liquidationThreshold": 0.8
        },
        "0x6b175474e89094c44da98b954eedeac495271d0f": {
            "tToken": "0x018008bfb33d285247a21d44e50697654f754e63",
            "sdToken": "0x413adac9e2ef8683adf5ddaece8f19613d60d1bb",
            "dToken": "0xcf8d0c70c850859266f5c338b38f9d663181c314",
            "liquidationThreshold": 0.8
        },
        "0xbe9895146f7af43049ca1c1ae358b0541ea49704": {
            "tToken": "0x977b6fc5de62598b08c85ac8cf2b745874e8b78c",
            "sdToken": "0x82be6012cea6d147b968ebaea5ceecf6a5b4f493",
            "dToken": "0x0c91bca95b5fe69164ce583a2ec9429a569798ed",
            "liquidationThreshold": 0.77
        },
        "0xdac17f958d2ee523a2206206994597c13d831ec7": {
            "tToken": "0x23878914efe38d27c4d67ab83ed1b93a74d4086a",
            "sdToken": "0x822fa72df1f229c3900f5ad6c3fa2c424d691622",
            "dToken": "0x6df1c1e379bc5a00a7b4c6e67a203333772f45a8",
            "liquidationThreshold": 0.76
        },
        "0xae78736cd615f374d3085123a210448e74fc6393": {
            "tToken": "0xcc9ee9483f662091a1de4795249e24ac0ac2630f",
            "sdToken": "0x1d1906f909cae494c7441604dafdddbd0485a925",
            "dToken": "0xae8593dd575fe29a9745056aa91c4b746eee62c8",
            "liquidationThreshold": 0.77
        },
        "0x83f20f44975d03b1b09e64809b757c47f942beea": {
            "tToken": "0x4c612e3b15b96ff9a6faed838f8d07d479a8dd4c",
            "sdToken": "0x48bc45f084988bc01933ea93eeffebc0416534f6",
            "dToken": "0x8db9d35e117d8b93c6ca9b644b25bad5d9908141",
            "liquidationThreshold": 0.8
        }
    }
}
